sword-web 0.3.0

Web controllers and runtime for the Sword framework
docs.rs failed to build sword-web-0.3.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.

sword-web

Web controllers and runtime for the Sword framework.

Built for the Sword framework: